Welcome to the dtFabric documentation
========================================

Data types fabric (dtFabric) is a YAML-based definition language to specify 
format and data types.

The source code is available from the `project page <https://github.com/libyal/dtfabric>`__.

.. toctree::
   :maxdepth: 2

   sources/user/index

.. toctree::
   :maxdepth: 2

   Format specification <sources/Format-specification>

.. toctree::
   :maxdepth: 2

   API documentation <sources/api/dtfabric>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`

